@@ -1,10 +1,10 @@
         integer maxn
-	parameter ( maxn = 200000 )
+	parameter ( maxn = 10000 )
         real*8  wzmin, wzmax, trackl
 	real*8  ke(maxn)
 	integer indx(maxn)
         integer nevent
-        integer outzero, check
+        integer outzero
         integer  pjcode, pjsub, pjchg
 	integer  tgcode, tgsub, tgchg
         integer  inpfileno, xyz
@@ -16,7 +16,7 @@
         common /Zotherc/ pj, tg, plab, ke, wzmin, wzmax, 
      *    trackl, pjpx, pjpy, pjpz, tgpx, tgpy, tgpz,
      *    xpos, ypos, zpos,  
-     *    indx, nevent, outzero, check,
+     *    indx, nevent, outzero,
      *    pjmnum, tgmnum, inpfileno, xyz,
      *	  pjcode, pjsub, pjchg,
      *	  tgcode, tgsub, tgchg
