@@ -10,7 +10,7 @@ c          block data names
 #include  "ZcosmosExt.h"
 
          integer ngen
-         character*120 msg
+c         character*120 msg
 
 
 c         if(MsgLevel -1 .ge. 0) then
