@@ -1,26 +1,26 @@
-      subroutine mediaCount(media, nmedia, compnToMn)
-c        assuming Zcnfig.h infromation is established, this
-c        subroutine counts no of different media and
-c        stores the media id in media.
-c
+      subroutine mediaCount(cmp, ncmp, media, nmedia)
+c       count number of different media in 'cmp' component 
       implicit none
+#include "ZepDraw.h"
 #include  "Zep3Vec.h"
 #include  "Zcnfig.h"
-
+      integer ncmp                ! input.  number of components in cmp
+      record /Component/ cmp(ncmp)   ! input.  
       integer nmedia    ! output.  No. of different media used.
       character*8 media(*)    ! output.  media(i) (i=1, nmedia) is media id.
-      integer compnToMn(*)    ! output.  compnToMn(i) (i=1, nct) is to convert
-                              ! component # to media # in "media".
+
 
       integer i, j
       character*8 mat
 c
-      if(Det.nct .gt. 0) then
+c      if(NumComp .gt. 0) then
+      if(ncmp .gt. 0) then
          nmedia = 1
          compnToMn(1) = 1
-         call epqmat(1, media(1))   ! inq. media
-         do i = 2, Det.nct
-            call epqmat(i, mat)
+         media(1) = cmp(1).matter
+c         do i = 2, NumComp
+         do i = 2, ncmp
+            mat = cmp(i).matter
             do j = 1, nmedia
                if(mat .eq. media(j)) then
                   compnToMn(i) =  j
